@@ -1,9 +1,10 @@
 import time
 from adafruit_esp32spi import adafruit_esp32spi_wifimanager
 import adafruit_esp32spi.adafruit_esp32spi_socket as socket
-import adafruit_minimqtt as MQTT
 import adafruit_pyportal
 
+import adafruit_minimqtt.adafruit_minimqtt as MQTT
+
 pyportal = adafruit_pyportal.PyPortal()
 
 ### WiFi ###
